<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="2.0" xmlns:xlink="http://www.w3.org/1999/xlink"
    xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance">
  <xsl:output method="xml" omit-xml-declaration="no" indent="yes" />
  
  <xsl:template match="/">
    <item>
      <xsl:apply-templates select="article | book" />
      <stripped-nlm>
        <xsl:apply-templates select="article | book" mode="partial-copy" />
      </stripped-nlm>
    </item>
  </xsl:template>
  
  <xsl:template match="article">
      <xsl:apply-templates select="front/article-meta" />
  </xsl:template>
  
  <xsl:template match="article/front/article-meta">
      <ti>
        <xsl:apply-templates select="title-group" />
      </ti>
      <atc>
        <xsl:apply-templates select="contrib-group" />
        <xsl:apply-templates select="title-group" />
        <xsl:apply-templates select="ancestor::front/journal-meta/journal-title-group | ancestor::front/book-meta/book-title-group" />
        <xsl:apply-templates select="volume" mode="value" />
        <xsl:apply-templates select="issue" mode="value" />
        <xsl:apply-templates select="fpage" mode="value" />
        <xsl:apply-templates select="lpage" mode="value" />
        <xsl:apply-templates select="pub-date/year" mode="value" />
      </atc>
  </xsl:template>
  
  <xsl:template match="book">
      <xsl:apply-templates select="front/book-meta" />
  </xsl:template>
  
  <xsl:template match="book/front/book-meta">
      <ti>
        <xsl:apply-templates select="book-title-group" />
      </ti>
      <atc>
        <xsl:apply-templates select="contrib-group" />
        <xsl:apply-templates select="book-title-group" />
        <xsl:apply-templates select="series[not(@content-type)]" mode="value" />
        <xsl:apply-templates select="publisher/publisher-loc" mode="value" />
        <xsl:apply-templates select="publisher/publisher-name" mode="value" />
        <xsl:apply-templates select="pub-date/year" mode="value" />
      </atc>
  </xsl:template>
  
  <xsl:template match="article-meta/title-group">
    <xsl:apply-templates select="article-title" />
    <xsl:apply-templates select="trans-title-group" />
  </xsl:template>
  
  <xsl:template match="article-meta/title-group/trans-title-group">
    <xsl:apply-templates select="trans-title" />
  </xsl:template>
  
  <xsl:template match="journal-meta/journal-title-group">
    <xsl:apply-templates select="abbrev-journal-title" mode="value" />
    <xsl:apply-templates select="journal-title" mode="value" />
  </xsl:template>
  
  <xsl:template match="book-meta/book-title-group">
    <xsl:apply-templates select="book-title" />
    <xsl:apply-templates select="subtitle" />
  </xsl:template>
  
  <xsl:template match="article-title | trans-title | book-title | subtitle">
    <xsl:apply-templates />
    <xsl:text> </xsl:text>
  </xsl:template>
  
  <xsl:template match="inline-formula | disp-formula">
    <xsl:apply-templates select="alternatives/tex-math" mode="value" />
  </xsl:template>

  <xsl:template match="contrib-group">
    <xsl:apply-templates select="contrib" />
  </xsl:template>
  
  <xsl:template match="contrib">
    <xsl:choose>
      <xsl:when test="string-name">
        <xsl:apply-templates select="string-name" mode="value" />
      </xsl:when>
      <xsl:otherwise>
        <xsl:apply-templates select="name" />
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>
  
  <xsl:template match="contrib/name">
    <xsl:value-of select="surname" />, <xsl:apply-templates select="given-names" mode="value" />
  </xsl:template>
  
  <xsl:template match="*" mode="value">
    <xsl:value-of select="." />
    <xsl:text> </xsl:text>
  </xsl:template>
  
  <xsl:template match="@* | node()" mode="partial-copy">
    <xsl:copy>
      <xsl:apply-templates select="@*|node()" mode="partial-copy" />
    </xsl:copy>
  </xsl:template>
  
  <xsl:template match="inline-formula | disp-formula" mode="partial-copy">
    <xsl:apply-templates select="alternatives/tex-math" mode="value" />
  </xsl:template>
  
  <xsl:template match="body|back|abstract|trans-abstract|ext-link|history|date|self-uri|custom-meta-group|issue-id|volume-id|kwd-group|issue-title|notes|related-article|address|email" mode="partial-copy" />
</xsl:stylesheet>
